<p align="center">
    <a target="_blank" href='https://url.cn/Z4lzPLaF'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F1040x100-tencent.jpg" width="100%"/>
    </a>   
</p>
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/office/robot.html">项目官网</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/PyOfficeRobot'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/PyOfficeRobot.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//PyOfficeRobot/'>
		<img src='https://gitee.com/CoderWanFeng//PyOfficeRobot/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/Jf_EVdKlVnHhK68fW5OA6A">
	<img src="https://img.shields.io/badge/QQ-1090738447-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/wx-JkgOUoJhb-7ZESxl93w">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>






# 又一个微信聊天机器人横空出世了，人人可用！


之前给大家分享过一个微信机器人：[一个15分钟的视频，教你用Python创建自己的微信聊天机器人！](http://t.cn/A66p30bI)

但是之前这个机器人，需要基于网页版才能用；然而很多朋友的微信，是不能登录网页版微信的。

> 有没有一种微信机器人，任何人的微信都可以用，不需要网页微信功能呢？


在经过技术检索和开发以后，支持所有微信使用的：**PyOfficeRobot**来啦~

## 1、安装PyOfficeRobot

1行命令，安装PyOfficeRobot这个库
```
pip install -i https://pypi.tuna.tsinghua.edu.cn/simple PyOfficeRobot -U
```

## 2、视频教程

- 💻[001-项目发布](https://www.bilibili.com/video/BV1Xa411u7yU)

- [002-发消息](https://www.bilibili.com/video/BV1Jt4y1j7F1)

- [003-发文件](https://www.bilibili.com/video/BV1te4y1y7Ro)

- [004-根据关键词，自动回复](https://www.bilibili.com/video/BV1fV4y1M7ju)

- [005-定时发送](https://www.bilibili.com/video/BV1m8411b7LZ)

- [006-自己加功能](https://www.bilibili.com/video/BV14R4y127h6)

- ⭐[007-独立使用](https://www.bilibili.com/video/BV1SY411y7Uh)

- 持续更新中，交流群：[点我加入](http://www.python4office.cn/wechat-group/)


## 3、功能Demo

我最近开源了这个库的全部源代码，功能正在开发中，欢迎大家参与开发~

- [演示代码](https://github.com/CoderWanFeng/PyOfficeRobot/tree/main/demo)


---

![](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg)


## ⭐Star 

[![Stargazers over time](https://starchart.cc/CoderWanFeng/PyOfficeRobot.svg)](https://starchart.cc/CoderWanFeng/PyOfficeRobot)


## 📕拓展资料


<p align="center" id='30讲自动化办公-banner'>
    <a target="_blank" href='http://gk.link/a/10E3B'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fauto-work.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/H3us6_7wg2QspGZfGtfDZw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='实战项目-banner'>
    <a target="_blank" href='http://www.python4office.cn/python-project-list/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fproject.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/uE1M8ESBQ3wJ_q-Cl1aNvg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/_01V8I7rVkgvIIo7ygwwQA'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='支付宝-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/TSnAjBs2dILSI_pM1pPznQ'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2Falipay.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='外卖-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/fdQ0TbTocPvw-DAMsFUlVg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2F%E5%A4%96%E5%8D%96-1040-100.jpg" width="100%"/>
    </a>   
</p>